@@ -176,33 +176,3 @@ class DatabaseConnection:
     def query_exists(self, query, data={}):
         return self._query(query, data, "exists")
 
-
-
-def entrypoint(context):
-    db = Database(context.config)
-
-    db.upsert_shop_id(8008135)
-    db.upsert_shop_id(1337)
-    db.upsert_shop_id(420)
-
-    shop69 = {"id": 69, "myshopify_name": "arne", "hostname": "arne", "last_page_source": "arne", "last_headers": "arne"}
-
-    shop420 = {"id": 420, "myshopify_name": "nils", "hostname": "nils", "last_page_source": "arne", "last_headers": "arne"}
-
-    db.upsert_shop(shop69)
-    db.upsert_shop(shop420)
-
-    ret = db.get_shops_by_score(10)
-    print(f"get_shops_by_score={ret}")
-
-    db.upsert_spop_id("site_id", "api_key", "input_link")
-    db.upsert_spop_id("site_id", "api_key", "input_link")
-    db.upsert_spop_id("site_id", "api_key", "input_link2")
-
-    ret = db.get_entries()
-    print(f"get_entries={ret}")
-
-
-# Main entrypoint of script
-if __name__ == "__main__":
-    entrypoint()
